==> i18n_plus-0.8.0.tar.gz: lib/i18n.dart <==
import 'package:flutter/widgets.dart';
import 'i18nMap.dart';

class I18N {
  static final I18N _i18n = I18N._internal();

  factory I18N() {
    return _i18n;
  }

  I18N._internal();

  I18NMap _i18nMap;
  ValueNotifier<Locale> _currentLocale = ValueNotifier(null);

  I18NMap get i18nMap => _i18nMap;
  ValueNotifier<Locale> get currentLocale => _currentLocale;

  ///This function is setting the Parameter [i18nMap]
  ///But only if
  ///the given [i18nMap] is valid.
  void seti18nMap(I18NMap i18nMap) {
    if (i18nMap.valid) {
      this._i18nMap = i18nMap;
      if (_currentLocale.value == null) {
        setCurrentLocale(i18nMap.languageSets.keys.toList()[0]);
      }
    } else {
      throw ("Cloudn't set i18nMap: Keys are not consistent throughout the languagesets");
    }
  }

  ///Returns all [Locale] as List from current [I18NMap]
  List<Locale> allLocale(){
    if(this._i18nMap != null){
      return this._i18nMap.languageSets.keys.toList();
    }
    return null;
  }

  ///Parameter [locale] will be set as the value of
  ///ValueNotifer [_currentLocale]
  ///If you want to change the language throughout all
  ///[I18NText] widgets do it with this function
  void setCurrentLocale(Locale locale) {
    this._currentLocale.value = locale;
  }

  ///Returns a specific String from the current [language set]
  ///Parameter [key] must not be null
  ///If parameter [locale] equals null, the current [language set]
  ///will be determined by the value of [_currentLocale]
  getI18nString(String key, Locale locale) {
    if (key != null && _currentLocale.value != null) {
      if (_i18nMap.languageSets[this._currentLocale.value][key] != null) {
        return _i18nMap.languageSets[locale == null ? this._currentLocale.value : locale][key];
      } else {
        throw ("Cannot retrieve String: Key cannot be found in language sets");
      }
    } else if (key == null && _currentLocale.value != null) {
      throw ("Cannot retrieve String: Key must not be null");
    } else if (_currentLocale.value == null && key != null) {
      throw ("Cannot retrieve String: Provide Locale");
    } else if (_currentLocale.value == null && key == null) {
      throw ("Cannot retrieve String: Provide Locale first\nCannot retrieve String: Key must not be null");
    }
  }
}

==> i18n_plus-0.8.6.tar.gz: lib/i18n.dart <==
import 'package:flutter/widgets.dart';
import 'i18nMap.dart';

class I18N {
  static final I18N _i18n = I18N._internal();

  factory I18N() {
    return _i18n;
  }

  I18N._internal();

  I18NMap _i18nMap;
  ValueNotifier<Locale> _currentLocale = ValueNotifier(null);

  ///Getter for current & valid [I18NMap]
  I18NMap get i18nMap => _i18nMap;
  ValueNotifier<Locale> get currentLocale => _currentLocale;

  ///This function is setting the Parameter [i18nMap]
  ///But only if
  ///the given [i18nMap] is valid.
  void seti18nMap(I18NMap i18nMap) {
    if (i18nMap.valid) {
      this._i18nMap = i18nMap;
      if (_currentLocale.value == null) {
        setCurrentLocale(i18nMap.languageSets[0].locale);
      }
    } else {
      throw ("Cloudn't set i18nMap: Keys are not consistent throughout the languagesets");
    }
  }

  ///Returns all [Locale] as List from current [I18NMap]
  List<Locale> allLocale() {
    if (this._i18nMap != null) {
      return this
          ._i18nMap
          .languageSets
          .map((languageset) => languageset.locale)
          .toList();
    }
    return null;
  }

  ///Parameter [locale] will be set as the value of
  ///ValueNotifer [_currentLocale]
  ///If you want to change the language throughout all
  ///[I18NText] widgets do it with this function
  void setCurrentLocale(Locale locale) {
    this._currentLocale.value = locale;
  }

  ///Returns a specific String from the current [language set]
  ///Parameter [key] must not be null
  ///If parameter [locale] equals null, the current [language set]
  ///will be determined by the value of [_currentLocale]
  getI18nString(String key, Locale locale) {
    if (key != null && locale == null) {
      if (_i18nMap.getWithLocale(this._currentLocale.value).map[key] != null) {
        return _i18nMap.getWithLocale(this._currentLocale.value).map[key];
      } else {
        throw ("Cannot retrieve String: Key cannot be found in language sets");
      }
    } else if (key != null &&
        locale != null &&
        _i18nMap.getWithLocale(locale) != null) {
      return _i18nMap.getWithLocale(locale).map[key];
    } else if (key == null) {
      throw ("Cannot retrieve String: Key must not be null");
    } else if (_currentLocale.value == null) {
      throw ("Cannot retrieve String: Default value is null");
    }
  }
}
